@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: compression.cpp 3946 2008-09-28 21:05:53Z mosu $
+   $Id: compression.cpp 4005 2008-11-01 10:51:26Z mosu $
 
    Helper routines for various compression libs
 
@@ -347,7 +347,7 @@ compressor_c::create(compression_method_e method) {
 
 compressor_ptr
 compressor_c::create(const char *method) {
-#if defined(HAVE_LZO1X_H)
+#if defined(HAVE_LZO)
   if (!strcasecmp(method, compression_methods[COMPRESSION_LZO]))
     return compressor_ptr(new lzo_compressor_c());
 #endif // HAVE_LZO1X_H
