@@ -5,7 +5,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: os.h 2711 2005-01-12 15:03:47Z mosu $
+   $Id: os.h 3940 2008-09-26 14:58:46Z mosu $
 
    Cross platform compatibility definitions
 
@@ -17,6 +17,9 @@
 
 #include "config.h"
 
+// For PRId64 and PRIu64:
+#define __STDC_FORMAT_MACROS
+
 #if defined(_WIN32) || defined(WIN32) || defined(__CYGWIN__) || defined(__MINGW32__)
 # define SYS_WINDOWS
 # if defined __MINGW32__
@@ -61,6 +64,16 @@ typedef _fsize_t ssize_t;
 #define PACKED_STRUCTURE   __attribute__((__packed__))
 #endif // COMP_MSC
 
+#if defined(HAVE_SYS_TYPES_H)
+# include <sys/types.h>
+#endif // HAVE_SYS_TYPES_H
+#if defined(HAVE_STDINT_H)
+# include <stdint.h>
+#endif // HAVE_STDINT_H
+#if defined(HAVE_INTTYPES_H)
+# include <inttypes.h>
+#endif // HAVE_INTTYPES_H
+
 #if defined(COMP_MINGW) || defined(COMP_MSC)
 
 // For DLL stuff...
@@ -74,25 +87,32 @@ typedef _fsize_t ssize_t;
 #  define MTX_DLL_API
 # endif
 
-# define LLD "%I64d"
-# define LLU "%I64u"
+# if defined(COMP_MINGW)
+// mingw is a special case. It does have inttypes.h declaring
+// PRId64 to be I64d, but it warns about "int type format, different
+// type argument" if %I64d is used with a int64_t. The mx* functions
+// convert %lld to %I64d on mingw/msvc anyway.
+#  undef PRId64
+#  define PRId64 "lld"
+#  undef PRIu64
+#  define PRIu64 "llu"
+#  undef PRIx64
+#  define PRIx64 "llx"
+# else
+// MSVC doesn't have inttypes, nor the PRI?64 defines.
+#  define PRId64 "I64d"
+#  define PRIu64 "I64u"
+#  define PRIx64 "I64x"
+# endif // defined(COMP_MINGW)
 
 #else  // COMP_MINGW || COMP_MSC
 
 # define MTX_DLL_API
-# define LLD "%lld"
-# define LLU "%llu"
+
 #endif // COMP_MINGW || COMP_MSC
 
-#if defined(HAVE_SYS_TYPES_H)
-#include <sys/types.h>
-#endif // HAVE_SYS_TYPES_H
-#if defined(HAVE_STDINT_H)
-#include <stdint.h>
-#endif // HAVE_STDINT_H
-#if defined(HAVE_INTTYPES_H)
-#include <inttypes.h>
-#endif // HAVE_INTTYPES_H
+#define LLD "%" PRId64
+#define LLU "%" PRIu64
 
 #if defined(HAVE_NO_INT64_T)
 typedef INT64_TYPE int64_t;
@@ -119,4 +139,8 @@ typedef UINT64_TYPE uint64_t;
 int vsscanf(const char *, const char *, va_list);
 #endif // !HAVE_VSSCANF...
 
+int MTX_DLL_API fs_entry_exists(const char *path);
+void MTX_DLL_API create_directory(const char *path);
+int64_t MTX_DLL_API get_current_time_millis();
+
 #endif
