@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: xml_element_mapping.cpp 3579 2007-08-19 08:53:32Z mosu $
+   $Id: xml_element_mapping.cpp 3946 2008-09-28 21:05:53Z mosu $
 
    Mapping from XML elements to EBML elements
 
@@ -45,9 +45,8 @@ init_mapping_table(parser_element_t *table) {
       table[i].name;
     result = find_ebml_callbacks(KaxSegment::ClassInfos, debug_name);
     if (NULL == result)
-      mxerror("Error initializing the tables for the chapter, tag and segment "
-              "info elements: Could not find the element with the debug name "
-              "'%s'. %s\n", debug_name, BUGMSG);
+      mxerror(boost::format(Y("Error initializing the tables for the chapter, tag and segment info elements: "
+                              "Could not find the element with the debug name '%1%'. %2%\n")) % debug_name % BUGMSG);
     table[i].id = result->GlobalId;
   }
 }
