@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: r_srt.h 3583 2007-08-19 18:35:51Z mosu $
+   $Id: r_srt.h 4008 2008-11-01 14:14:06Z mosu $
 
    class definition for the Subripper subtitle reader
 
@@ -18,8 +18,6 @@
 
 #include "os.h"
 
-#include <stdio.h>
-
 #include "mm_io.h"
 #include "common.h"
 #include "pr_generic.h"
@@ -27,15 +25,13 @@
 
 class srt_reader_c: public generic_reader_c {
 private:
-  mm_text_io_c *io;
-  subtitles_c subs;
-  bool m_coordinates_warning_shown;
+  mm_text_io_cptr m_io;
+  srt_parser_cptr m_subs;
 
 public:
   srt_reader_c(track_info_c &_ti) throw (error_c);
   virtual ~srt_reader_c();
 
-  virtual void parse_file();
   virtual file_status_e read(generic_packetizer_c *ptzr, bool force = false);
   virtual void identify();
   virtual void create_packetizer(int64_t tid);
