@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: libmatroska_extensions.h 3518 2007-03-15 20:33:34Z mosu $
+   $Id: libmatroska_extensions.h 3978 2008-10-09 07:50:55Z mosu $
 
    The cluster helper groups frames into blocks groups and those
    into clusters, sets the durations, renders the clusters etc.
@@ -50,7 +50,7 @@ public:
   kax_reference_block_c();
 
   void set_value(int64_t value) {
-    m_value = value;
+    m_value     = value;
     bValueIsSet = true;
   }
 
@@ -62,9 +62,7 @@ public:
   kax_block_group_c(): KaxBlockGroup() {
   }
 
-  bool add_frame(const KaxTrackEntry &track, uint64 timecode,
-                 DataBuffer &buffer, int64_t past_block, int64_t forw_block,
-                 LacingType lacing);
+  bool add_frame(const KaxTrackEntry &track, uint64 timecode, DataBuffer &buffer, int64_t past_block, int64_t forw_block, LacingType lacing);
 };
 
 class kax_block_blob_c: public KaxBlockBlob {
@@ -72,9 +70,7 @@ public:
   kax_block_blob_c(BlockBlobType type): KaxBlockBlob(type) {
   }
 
-  bool add_frame_auto(const KaxTrackEntry &track, uint64 timecode,
-                      DataBuffer &buffer, LacingType lacing,
-                      int64_t past_block, int64_t forw_block);
+  bool add_frame_auto(const KaxTrackEntry &track, uint64 timecode, DataBuffer &buffer, LacingType lacing, int64_t past_block, int64_t forw_block);
   void set_block_duration(uint64_t time_length);
   bool replace_simple_by_group();
 };
