@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: mux_dialog.cpp 3946 2008-09-28 21:05:53Z mosu $
+   $Id: mux_dialog.cpp 4025 2008-12-03 15:17:04Z mosu $
 
    muxing dialog
 
@@ -151,11 +151,19 @@ mux_dialog::mux_dialog(wxWindow *parent):
   line = "";
   log = wxT("");
   while (1) {
-    if (!out->Eof())
-      c = out->GetC();
     while (app->Pending())
       app->Dispatch();
 
+    if (!out->CanRead() && !out->Eof()) {
+      wxMilliSleep(5);
+      continue;
+    }
+
+    if (!out->Eof())
+      c = out->GetC();
+    else
+      c = '\n';
+
     if ((c == '\n') || (c == '\r') || out->Eof()) {
 #if WXUNICODE
       wx_line = wxU(line.c_str());
