@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: p_aac.h 3838 2008-08-21 15:04:24Z mosu $
+   $Id: p_aac.h 3950 2008-09-30 22:35:14Z mosu $
 
    class definition for the AAC output module
 
@@ -25,17 +25,15 @@
 
 class aac_packetizer_c: public generic_packetizer_c {
 private:
-  int64_t bytes_output, packetno, last_timecode, num_packets_same_tc;
-  int64_t bytes_skipped;
-  int samples_per_sec, channels, id, profile;
-  bool headerless, emphasis_present;
-  byte_buffer_c byte_buffer;
+  int64_t m_bytes_output, m_packetno, m_last_timecode, m_num_packets_same_tc;
+  int64_t m_bytes_skipped;
+  int m_samples_per_sec, m_channels, m_id, m_profile;
+  bool m_headerless, m_emphasis_present;
+  byte_buffer_c m_byte_buffer;
 
 public:
-  aac_packetizer_c(generic_reader_c *_reader, int _id, int _profile,
-                   int _samples_per_sec, int _channels,
-                   track_info_c &_ti, bool emphasis_present,
-                   bool _headerless = false) throw (error_c);
+  aac_packetizer_c(generic_reader_c *p_reader, track_info_c &p_ti, int id, int profile, int samples_per_sec, int channels,
+                   bool emphasis_present, bool _headerless = false) throw (error_c);
   virtual ~aac_packetizer_c();
 
   virtual int process(packet_cptr packet);
@@ -44,12 +42,11 @@ public:
   virtual const char *get_format_name() {
     return "AAC";
   }
-  virtual connection_result_e can_connect_to(generic_packetizer_c *src,
-                                             string &error_message);
+
+  virtual connection_result_e can_connect_to(generic_packetizer_c *src, string &error_message);
 
 private:
-  virtual unsigned char *get_aac_packet(unsigned long *header,
-                                        aac_header_t *aacheader);
+  virtual unsigned char *get_aac_packet(unsigned long *header, aac_header_t *aacheader);
   virtual int process_headerless(packet_cptr packet);
 };
 
