@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: p_avc.cpp 3950 2008-09-30 22:35:14Z mosu $
+   $Id: p_avc.cpp 4013 2008-11-04 16:29:37Z mosu $
 
    MPEG 4 part 10 ES video output module
 
@@ -97,7 +97,7 @@ mpeg4_p10_es_video_packetizer_c::process(packet_cptr packet) {
     mxerror_tid(ti.fname, ti.id,
                 boost::format(Y("mkvmerge encountered broken or unparsable data in this AVC/h.264 video track. "
                                 "Either your file is damaged (which mkvmerge cannot cope with yet) or this is a bug in mkvmerge itself. "
-                                "The error message was:\n")) % error.get_error());
+                                "The error message was:\n%1%\n")) % error.get_error());
   }
 
   return FILE_STATUS_MOREDATA;
